@@ -30,10 +30,10 @@ func TestDomainService_GetAll(t *testing.T) {
 	require.NoError(t, err)
 
 	expected := []Domain{
-		{ID: 273301, Name: "aaa.wtf", TypeID: 1, Version: 9, Status: "ACTIVE"},
-		{ID: 273302, Name: "bbb.wtf", TypeID: 1, Version: 9, Status: "ACTIVE"},
-		{ID: 273303, Name: "ccc.wtf", TypeID: 1, Version: 9, Status: "ACTIVE"},
-		{ID: 273304, Name: "ddd.wtf", TypeID: 1, Version: 9, Status: "ACTIVE"},
+		{ID: 273301, Name: "aaa.example", TypeID: 1, Version: 9, Status: "ACTIVE"},
+		{ID: 273302, Name: "bbb.example", TypeID: 1, Version: 9, Status: "ACTIVE"},
+		{ID: 273303, Name: "ccc.example", TypeID: 1, Version: 9, Status: "ACTIVE"},
+		{ID: 273304, Name: "ddd.example", TypeID: 1, Version: 9, Status: "ACTIVE"},
 	}
 
 	assert.Equal(t, expected, data)
@@ -44,14 +44,14 @@ func TestDomainService_Search(t *testing.T) {
 		Route("GET /v1/domains/search",
 			servermock.ResponseFromFixture("domains-Search.json"),
 			servermock.CheckQueryParameter().Strict().
-				With("exact", "lego.wtf")).
+				With("exact", "example.com")).
 		Build(t)
 
-	data, err := client.Domains.Search(t.Context(), Exact, "lego.wtf")
+	data, err := client.Domains.Search(t.Context(), Exact, "example.com")
 	require.NoError(t, err)
 
 	expected := []Domain{
-		{ID: 273302, Name: "lego.wtf", TypeID: 1, Version: 9, Status: "ACTIVE"},
+		{ID: 273302, Name: "example.com", TypeID: 1, Version: 9, Status: "ACTIVE"},
 	}
 
 	assert.Equal(t, expected, data)
