@@ -11,6 +11,7 @@ import (
 	"github.com/go-acme/lego/v4/challenge"
 	"github.com/go-acme/lego/v4/challenge/dns01"
 	"github.com/go-acme/lego/v4/platform/config/env"
+	"github.com/go-acme/lego/v4/providers/dns/internal/clientdebug"
 	"github.com/nrdcg/dnspod-go"
 )
 
@@ -82,7 +83,12 @@ func NewDNSProviderConfig(config *Config) (*DNSProvider, error) {
 	params := dnspod.CommonParams{LoginToken: config.LoginToken, Format: "json"}
 
 	client := dnspod.NewClient(params)
-	client.HTTPClient = config.HTTPClient
+
+	if config.HTTPClient != nil {
+		client.HTTPClient = config.HTTPClient
+	}
+
+	client.HTTPClient = clientdebug.Wrap(client.HTTPClient)
 
 	return &DNSProvider{client: client, config: config}, nil
 }
@@ -129,6 +135,7 @@ func (d *DNSProvider) CleanUp(domain, token, keyAuth string) error {
 			return err
 		}
 	}
+
 	return nil
 }
 
@@ -150,6 +157,7 @@ func (d *DNSProvider) getHostedZone(domain string) (string, string, error) {
 	}
 
 	var hostedZone dnspod.Domain
+
 	for _, zone := range zones {
 		if zone.Name == dns01.UnFqdn(authZone) {
 			hostedZone = zone
@@ -185,6 +193,7 @@ func (d *DNSProvider) findTxtRecords(fqdn, zoneID, zoneName string) ([]dnspod.Re
 	}
 
 	var records []dnspod.Record
+
 	result, _, err := d.client.Records.List(zoneID, subDomain)
 	if err != nil {
 		return records, fmt.Errorf("API call has failed: %w", err)
