@@ -11,15 +11,18 @@ import (
 	"time"
 
 	"cloud.google.com/go/compute/metadata"
+	"github.com/cenkalti/backoff/v5"
 	"github.com/go-acme/lego/v4/challenge"
 	"github.com/go-acme/lego/v4/challenge/dns01"
 	"github.com/go-acme/lego/v4/log"
 	"github.com/go-acme/lego/v4/platform/config/env"
 	"github.com/go-acme/lego/v4/platform/wait"
+	"github.com/go-acme/lego/v4/providers/dns/internal/clientdebug"
+	"github.com/miekg/dns"
 	"golang.org/x/net/context"
 	"golang.org/x/oauth2"
 	"golang.org/x/oauth2/google"
-	"google.golang.org/api/dns/v1"
+	gdns "google.golang.org/api/dns/v1"
 	"google.golang.org/api/googleapi"
 	"google.golang.org/api/impersonate"
 	"google.golang.org/api/option"
@@ -74,7 +77,7 @@ func NewDefaultConfig() *Config {
 // DNSProvider implements the challenge.Provider interface.
 type DNSProvider struct {
 	config *Config
-	client *dns.Service
+	client *gdns.Service
 }
 
 // NewDNSProvider returns a DNSProvider instance configured for Google Cloud DNS.
@@ -90,6 +93,7 @@ func NewDNSProvider() (*DNSProvider, error) {
 
 	// Use default credentials.
 	project := env.GetOrDefaultString(EnvProject, autodetectProjectID(context.Background()))
+
 	return NewDNSProviderCredentials(project)
 }
 
@@ -104,6 +108,7 @@ func NewDNSProviderCredentials(project string) (*DNSProvider, error) {
 	config.Project = project
 
 	var err error
+
 	config.HTTPClient, err = newClientFromCredentials(context.Background(), config)
 	if err != nil {
 		return nil, fmt.Errorf("googlecloud: %w", err)
@@ -127,10 +132,12 @@ func NewDNSProviderServiceAccountKey(saKey []byte) (*DNSProvider, error) {
 		var datJSON struct {
 			ProjectID string `json:"project_id"`
 		}
+
 		err := json.Unmarshal(saKey, &datJSON)
 		if err != nil || datJSON.ProjectID == "" {
 			return nil, errors.New("googlecloud: project ID not found in Google Cloud Service Account file")
 		}
+
 		project = datJSON.ProjectID
 	}
 
@@ -138,6 +145,7 @@ func NewDNSProviderServiceAccountKey(saKey []byte) (*DNSProvider, error) {
 	config.Project = project
 
 	var err error
+
 	config.HTTPClient, err = newClientFromServiceAccountKey(context.Background(), config, saKey)
 	if err != nil {
 		return nil, fmt.Errorf("googlecloud: %w", err)
@@ -166,11 +174,12 @@ func NewDNSProviderConfig(config *Config) (*DNSProvider, error) {
 	if config == nil {
 		return nil, errors.New("googlecloud: the configuration of the DNS provider is nil")
 	}
+
 	if config.HTTPClient == nil {
 		return nil, errors.New("googlecloud: unable to create Google Cloud DNS service: client is nil")
 	}
 
-	svc, err := dns.NewService(context.Background(), option.WithHTTPClient(config.HTTPClient))
+	svc, err := gdns.NewService(context.Background(), option.WithHTTPClient(clientdebug.Wrap(config.HTTPClient)))
 	if err != nil {
 		return nil, fmt.Errorf("googlecloud: unable to create Google Cloud DNS service: %w", err)
 	}
@@ -180,6 +189,8 @@ func NewDNSProviderConfig(config *Config) (*DNSProvider, error) {
 
 // Present creates a TXT record to fulfill the dns-01 challenge.
 func (d *DNSProvider) Present(domain, token, keyAuth string) error {
+	ctx := context.Background()
+
 	info := dns01.GetChallengeInfo(domain, keyAuth)
 
 	zone, err := d.getHostedZone(info.EffectiveFQDN)
@@ -195,6 +206,7 @@ func (d *DNSProvider) Present(domain, token, keyAuth string) error {
 
 	for _, rrSet := range existingRrSet {
 		var rrd []string
+
 		for _, rr := range rrSet.Rrdatas {
 			data := mustUnquote(rr)
 			rrd = append(rrd, data)
@@ -204,17 +216,18 @@ func (d *DNSProvider) Present(domain, token, keyAuth string) error {
 				return nil
 			}
 		}
+
 		rrSet.Rrdatas = rrd
 	}
 
 	// Attempt to delete the existing records before adding the new one.
 	if len(existingRrSet) > 0 {
-		if err = d.applyChanges(zone, &dns.Change{Deletions: existingRrSet}); err != nil {
+		if err = d.applyChanges(ctx, zone, &gdns.Change{Deletions: existingRrSet}); err != nil {
 			return fmt.Errorf("googlecloud: %w", err)
 		}
 	}
 
-	rec := &dns.ResourceRecordSet{
+	rec := &gdns.ResourceRecordSet{
 		Name:    info.EffectiveFQDN,
 		Rrdatas: []string{info.Value},
 		Ttl:     int64(d.config.TTL),
@@ -230,18 +243,18 @@ func (d *DNSProvider) Present(domain, token, keyAuth string) error {
 		}
 	}
 
-	change := &dns.Change{
-		Additions: []*dns.ResourceRecordSet{rec},
+	change := &gdns.Change{
+		Additions: []*gdns.ResourceRecordSet{rec},
 	}
 
-	if err = d.applyChanges(zone, change); err != nil {
+	if err = d.applyChanges(ctx, zone, change); err != nil {
 		return fmt.Errorf("googlecloud: %w", err)
 	}
 
 	return nil
 }
 
-func (d *DNSProvider) applyChanges(zone string, change *dns.Change) error {
+func (d *DNSProvider) applyChanges(ctx context.Context, zone string, change *gdns.Change) error {
 	if d.config.Debug {
 		data, _ := json.Marshal(change)
 		log.Printf("change (Create): %s", string(data))
@@ -255,6 +268,7 @@ func (d *DNSProvider) applyChanges(zone string, change *dns.Change) error {
 		}
 
 		data, _ := json.Marshal(change)
+
 		return fmt.Errorf("failed to perform changes [zone %s, change %s]: %w", zone, string(data), err)
 	}
 
@@ -265,24 +279,28 @@ func (d *DNSProvider) applyChanges(zone string, change *dns.Change) error {
 	chgID := chg.Id
 
 	// wait for change to be acknowledged
-	return wait.For("apply change", 30*time.Second, 3*time.Second, func() (bool, error) {
-		if d.config.Debug {
-			data, _ := json.Marshal(change)
-			log.Printf("change (Get): %s", string(data))
-		}
+	return wait.Retry(ctx,
+		func() error {
+			if d.config.Debug {
+				data, _ := json.Marshal(change)
+				log.Printf("change (Get): %s", string(data))
+			}
 
-		chg, err = d.client.Changes.Get(d.config.Project, zone, chgID).Do()
-		if err != nil {
-			data, _ := json.Marshal(change)
-			return false, fmt.Errorf("failed to get changes [zone %s, change %s]: %w", zone, string(data), err)
-		}
+			chg, err = d.client.Changes.Get(d.config.Project, zone, chgID).Do()
+			if err != nil {
+				data, _ := json.Marshal(change)
+				return fmt.Errorf("failed to get changes [zone %s, change %s]: %w", zone, string(data), err)
+			}
 
-		if chg.Status == changeStatusDone {
-			return true, nil
-		}
+			if chg.Status != changeStatusDone {
+				return fmt.Errorf("status: %s", chg.Status)
+			}
 
-		return false, fmt.Errorf("status: %s", chg.Status)
-	})
+			return nil
+		},
+		backoff.WithBackOff(backoff.NewConstantBackOff(3*time.Second)),
+		backoff.WithMaxElapsedTime(30*time.Second),
+	)
 }
 
 // CleanUp removes the TXT record matching the specified parameters.
@@ -303,10 +321,11 @@ func (d *DNSProvider) CleanUp(domain, token, keyAuth string) error {
 		return nil
 	}
 
-	_, err = d.client.Changes.Create(d.config.Project, zone, &dns.Change{Deletions: records}).Do()
+	_, err = d.client.Changes.Create(d.config.Project, zone, &gdns.Change{Deletions: records}).Do()
 	if err != nil {
 		return fmt.Errorf("googlecloud: %w", err)
 	}
+
 	return nil
 }
 
@@ -352,7 +371,7 @@ func (d *DNSProvider) getHostedZone(domain string) (string, error) {
 //	(gcloud projects get-iam-policy $project_id) (a role with permission dns.managedZones.list)
 //
 // If we force a zone list to succeed, we demand more permissions than needed.
-func (d *DNSProvider) lookupHostedZoneID(domain string) (string, []*dns.ManagedZone, error) {
+func (d *DNSProvider) lookupHostedZoneID(domain string) (string, []*gdns.ManagedZone, error) {
 	// GCE_ZONE_ID override for service accounts to avoid needing zones-list permission
 	if d.config.ZoneID != "" {
 		zone, err := d.client.ManagedZones.Get(d.config.Project, d.config.ZoneID).Do()
@@ -360,10 +379,10 @@ func (d *DNSProvider) lookupHostedZoneID(domain string) (string, []*dns.ManagedZ
 			return "", nil, fmt.Errorf("API call ManagedZones.Get for explicit zone ID %q in project %q failed: %w", d.config.ZoneID, d.config.Project, err)
 		}
 
-		return zone.DnsName, []*dns.ManagedZone{zone}, nil
+		return zone.DnsName, []*gdns.ManagedZone{zone}, nil
 	}
 
-	authZone, err := dns01.FindZoneByFqdn(dns01.ToFqdn(domain))
+	authZone, err := dns01.FindZoneByFqdn(dns.Fqdn(domain))
 	if err != nil {
 		return "", nil, fmt.Errorf("could not find zone: %w", err)
 	}
@@ -379,7 +398,7 @@ func (d *DNSProvider) lookupHostedZoneID(domain string) (string, []*dns.ManagedZ
 	return authZone, zones.ManagedZones, nil
 }
 
-func (d *DNSProvider) findTxtRecords(zone, fqdn string) ([]*dns.ResourceRecordSet, error) {
+func (d *DNSProvider) findTxtRecords(zone, fqdn string) ([]*gdns.ResourceRecordSet, error) {
 	recs, err := d.client.ResourceRecordSets.List(d.config.Project, zone).Name(fqdn).Type("TXT").Do()
 	if err != nil {
 		return nil, err
@@ -398,7 +417,7 @@ func newClientFromCredentials(ctx context.Context, config *Config) (*http.Client
 		return newImpersonateClient(ctx, config.ImpersonateServiceAccount, ts)
 	}
 
-	client, err := google.DefaultClient(ctx, dns.NdevClouddnsReadwriteScope)
+	client, err := google.DefaultClient(ctx, gdns.NdevClouddnsReadwriteScope)
 	if err != nil {
 		return nil, fmt.Errorf("unable to get Google Cloud client: %w", err)
 	}
@@ -416,7 +435,7 @@ func newClientFromServiceAccountKey(ctx context.Context, config *Config, saKey [
 		return newImpersonateClient(ctx, config.ImpersonateServiceAccount, conf.TokenSource(ctx))
 	}
 
-	conf, err := google.JWTConfigFromJSON(saKey, dns.NdevClouddnsReadwriteScope)
+	conf, err := google.JWTConfigFromJSON(saKey, gdns.NdevClouddnsReadwriteScope)
 	if err != nil {
 		return nil, fmt.Errorf("unable to acquire config: %w", err)
 	}
@@ -427,7 +446,7 @@ func newClientFromServiceAccountKey(ctx context.Context, config *Config, saKey [
 func newImpersonateClient(ctx context.Context, impersonateServiceAccount string, ts oauth2.TokenSource) (*http.Client, error) {
 	impersonatedTS, err := impersonate.CredentialsTokenSource(ctx, impersonate.CredentialsConfig{
 		TargetPrincipal: impersonateServiceAccount,
-		Scopes:          []string{dns.NdevClouddnsReadwriteScope},
+		Scopes:          []string{gdns.NdevClouddnsReadwriteScope},
 	}, option.WithTokenSource(ts))
 	if err != nil {
 		return nil, fmt.Errorf("unable to create impersonated credentials: %w", err)
@@ -441,6 +460,7 @@ func mustUnquote(raw string) string {
 	if err != nil {
 		return raw
 	}
+
 	return clean
 }
 
